pkgconf: An implementation of the pkg-config spec
=================================================

Description
-----------

Pkgconf is an implementation of the pkg-config spec with minimal
dependencies.

License
-------

ISC License (equivalent to Simplified BSD)


Upstream Contact
----------------

https://github.com/pkgconf/pkgconf

Special Update/Build Instructions
---------------------------------

-  install.patch: Use install script from AC_PROG_INSTALL

Pkgconf is used in bzip2, so we must not use the bzip2-compressed
tarball.
